document.addEventListener("DOMContentLoaded", () => {
  const dropZone = document.getElementById("dropZone");
  const fileInput = document.getElementById("fileInput");
  const layersList = document.getElementById("layersList");
  const canvas = document.getElementById("previewCanvas");
  const ctx = canvas.getContext("2d");
  const downloadBtn = document.getElementById("downloadBtn");

  let images = [];

  function handleFiles(files) {
    const pngFiles = Array.from(files).filter(
      (file) => file.type === "image/png",
    );

    pngFiles.forEach((file) => {
      const reader = new FileReader();
      reader.onload = (e) => {
        const img = new Image();
        img.onload = () => {
          console.log(`Loaded image: ${file.name}`);
          console.log(`Dimensions: ${img.naturalWidth} x ${img.naturalHeight}`);

          images.push({
            element: img,
            name: file.name,
            width: img.naturalWidth,
            height: img.naturalHeight,
          });
          updateLayers();
          renderPreview();
        };
        img.src = e.target.result;
      };
      reader.readAsDataURL(file);
    });
  }

  function updateLayers() {
    layersList.innerHTML = "";
    images.forEach((image, index) => {
      const li = document.createElement("li");
      li.className = "layer-item";
      li.innerHTML = `
        <span>${image.name} (${image.width}x${image.height})</span>
        <div>
          ${index > 0 ? `<button onclick="moveLayer(${index}, -1)">↑</button>` : ""}
          ${index < images.length - 1 ? `<button onclick="moveLayer(${index}, 1)">↓</button>` : ""}
          <button onclick="removeLayer(${index})">×</button>
        </div>
      `;
      layersList.appendChild(li);
    });

    downloadBtn.disabled = images.length === 0;
  }

  function renderPreview() {
    if (images.length === 0) {
      canvas.width = 300;
      canvas.height = 300;
      ctx.clearRect(0, 0, canvas.width, canvas.height);
      return;
    }

    // Calculate total height and maximum width
    const totalHeight = images.reduce((sum, img) => sum + img.height, 0);
    const maxWidth = Math.max(...images.map((img) => img.width));

    console.log("Calculated dimensions:");
    console.log(`Total Height: ${totalHeight}`);
    console.log(`Max Width: ${maxWidth}`);

    // Set canvas dimensions BEFORE any drawing
    canvas.width = maxWidth;
    canvas.height = totalHeight;

    console.log("Canvas dimensions after setting:");
    console.log(`Canvas: ${canvas.width} x ${canvas.height}`);

    // Clear the entire canvas
    ctx.clearRect(0, 0, maxWidth, totalHeight);

    // Draw images
    let yPosition = 0;
    images.forEach((image, index) => {
      console.log(`Drawing image ${index} at y=${yPosition}`);
      ctx.drawImage(image.element, 0, yPosition);
      yPosition += image.height;
    });
  }

  window.moveLayer = (index, direction) => {
    const newIndex = index + direction;
    [images[index], images[newIndex]] = [images[newIndex], images[index]];
    updateLayers();
    renderPreview();
  };

  window.removeLayer = (index) => {
    images.splice(index, 1);
    updateLayers();
    renderPreview();
  };

  dropZone.addEventListener("click", () => fileInput.click());

  fileInput.addEventListener("change", (e) => {
    handleFiles(e.target.files);
    fileInput.value = "";
  });

  dropZone.addEventListener("dragover", (e) => {
    e.preventDefault();
    dropZone.classList.add("drag-over");
  });

  dropZone.addEventListener("dragleave", () => {
    dropZone.classList.remove("drag-over");
  });

  dropZone.addEventListener("drop", (e) => {
    e.preventDefault();
    dropZone.classList.remove("drag-over");
    handleFiles(e.dataTransfer.files);
  });

  downloadBtn.addEventListener("click", () => {
    const link = document.createElement("a");
    link.download = "merged-image.png";
    link.href = canvas.toDataURL("image/png");
    link.click();
  });
});
